==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/dir_06983a04f4bcdd04d40946e8be932ce3.js <==
var dir_06983a04f4bcdd04d40946e8be932ce3 =
[
    [ "allegro_s.cpp", "d3/d3d/allegro__s_8cpp.html", null ],
    [ "allegro_s.h", "db/d6e/allegro__s_8h.html", [
      [ "SoundDriver_Allegro", "d8/d7e/classSoundDriver__Allegro.html", "d8/d7e/classSoundDriver__Allegro" ],
      [ "FSoundDriver_Allegro", "de/dc8/classFSoundDriver__Allegro.html", "de/dc8/classFSoundDriver__Allegro" ]
    ] ],
    [ "cocoa_s.cpp", "d9/d59/cocoa__s_8cpp.html", null ],
    [ "cocoa_s.h", "d9/dc2/cocoa__s_8h.html", [
      [ "SoundDriver_Cocoa", "d2/d35/classSoundDriver__Cocoa.html", "d2/d35/classSoundDriver__Cocoa" ],
      [ "FSoundDriver_Cocoa", "d0/d49/classFSoundDriver__Cocoa.html", "d0/d49/classFSoundDriver__Cocoa" ]
    ] ],
    [ "null_s.cpp", "d7/dfe/null__s_8cpp.html", "d7/dfe/null__s_8cpp" ],
    [ "null_s.h", "dd/dfb/null__s_8h.html", [
      [ "SoundDriver_Null", "db/ddd/classSoundDriver__Null.html", "db/ddd/classSoundDriver__Null" ],
      [ "FSoundDriver_Null", "d7/d30/classFSoundDriver__Null.html", "d7/d30/classFSoundDriver__Null" ]
    ] ],
    [ "sdl_s.cpp", "d5/d97/sdl__s_8cpp.html", "d5/d97/sdl__s_8cpp" ],
    [ "sdl_s.h", "d8/d87/sdl__s_8h.html", [
      [ "SoundDriver_SDL", "d8/d1d/classSoundDriver__SDL.html", "d8/d1d/classSoundDriver__SDL" ],
      [ "FSoundDriver_SDL", "dd/dda/classFSoundDriver__SDL.html", "dd/dda/classFSoundDriver__SDL" ]
    ] ],
    [ "sound_driver.hpp", "d8/dca/sound__driver_8hpp.html", "d8/dca/sound__driver_8hpp" ],
    [ "win32_s.cpp", "d5/dd8/win32__s_8cpp.html", "d5/dd8/win32__s_8cpp" ],
    [ "win32_s.h", "d8/d12/win32__s_8h.html", [
      [ "SoundDriver_Win32", "df/df6/classSoundDriver__Win32.html", "df/df6/classSoundDriver__Win32" ],
      [ "FSoundDriver_Win32", "d1/d57/classFSoundDriver__Win32.html", "d1/d57/classFSoundDriver__Win32" ]
    ] ],
    [ "xaudio2_s.cpp", "da/d4f/xaudio2__s_8cpp.html", null ],
    [ "xaudio2_s.h", "d0/d1d/xaudio2__s_8h.html", [
      [ "SoundDriver_XAudio2", "d1/dce/classSoundDriver__XAudio2.html", "d1/dce/classSoundDriver__XAudio2" ],
      [ "FSoundDriver_XAudio2", "d0/d1a/classFSoundDriver__XAudio2.html", "d0/d1a/classFSoundDriver__XAudio2" ]
    ] ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/dir_06983a04f4bcdd04d40946e8be932ce3.js <==
var dir_06983a04f4bcdd04d40946e8be932ce3 =
[
    [ "allegro_s.cpp", "d3/d3d/allegro__s_8cpp.html", null ],
    [ "allegro_s.h", "db/d6e/allegro__s_8h.html", [
      [ "SoundDriver_Allegro", "d8/d7e/classSoundDriver__Allegro.html", "d8/d7e/classSoundDriver__Allegro" ],
      [ "FSoundDriver_Allegro", "de/dc8/classFSoundDriver__Allegro.html", "de/dc8/classFSoundDriver__Allegro" ]
    ] ],
    [ "cocoa_s.cpp", "d9/d59/cocoa__s_8cpp.html", null ],
    [ "cocoa_s.h", "d9/dc2/cocoa__s_8h.html", [
      [ "SoundDriver_Cocoa", "d2/d35/classSoundDriver__Cocoa.html", "d2/d35/classSoundDriver__Cocoa" ],
      [ "FSoundDriver_Cocoa", "d0/d49/classFSoundDriver__Cocoa.html", "d0/d49/classFSoundDriver__Cocoa" ]
    ] ],
    [ "null_s.cpp", "d7/dfe/null__s_8cpp.html", "d7/dfe/null__s_8cpp" ],
    [ "null_s.h", "dd/dfb/null__s_8h.html", [
      [ "SoundDriver_Null", "db/ddd/classSoundDriver__Null.html", "db/ddd/classSoundDriver__Null" ],
      [ "FSoundDriver_Null", "d7/d30/classFSoundDriver__Null.html", "d7/d30/classFSoundDriver__Null" ]
    ] ],
    [ "sdl2_s.cpp", "dd/d97/sdl2__s_8cpp.html", null ],
    [ "sdl_s.cpp", "d5/d97/sdl__s_8cpp.html", "d5/d97/sdl__s_8cpp" ],
    [ "sdl_s.h", "d8/d87/sdl__s_8h.html", [
      [ "SoundDriver_SDL", "d8/d1d/classSoundDriver__SDL.html", "d8/d1d/classSoundDriver__SDL" ],
      [ "FSoundDriver_SDL", "dd/dda/classFSoundDriver__SDL.html", "dd/dda/classFSoundDriver__SDL" ]
    ] ],
    [ "sound_driver.hpp", "d8/dca/sound__driver_8hpp.html", "d8/dca/sound__driver_8hpp" ],
    [ "win32_s.cpp", "d5/dd8/win32__s_8cpp.html", "d5/dd8/win32__s_8cpp" ],
    [ "win32_s.h", "d8/d12/win32__s_8h.html", [
      [ "SoundDriver_Win32", "df/df6/classSoundDriver__Win32.html", "df/df6/classSoundDriver__Win32" ],
      [ "FSoundDriver_Win32", "d1/d57/classFSoundDriver__Win32.html", "d1/d57/classFSoundDriver__Win32" ]
    ] ],
    [ "xaudio2_s.cpp", "da/d4f/xaudio2__s_8cpp.html", "da/d4f/xaudio2__s_8cpp" ],
    [ "xaudio2_s.h", "d0/d1d/xaudio2__s_8h.html", [
      [ "SoundDriver_XAudio2", "d1/dce/classSoundDriver__XAudio2.html", "d1/dce/classSoundDriver__XAudio2" ],
      [ "FSoundDriver_XAudio2", "d0/d1a/classFSoundDriver__XAudio2.html", "d0/d1a/classFSoundDriver__XAudio2" ]
    ] ]
];
